# sxm-viewer

## About

A PyQt5 based tool for inspecting *.sxm files and save them as figures swiftly.

This tool aims to inspect and save figures fast.
Load a folder, and use up/down to switch the files swiftly. Press key S to save the .png file into the configured folder(in config.ini) directly.
Suppress this help in config.ini.
Have fun! 


## Install
```
pip install sxm_viewer
```

## Usage
```
sxmv
```

## Versions

- version 0.2 on 2021/1/7: add options pane. You can change your colormap, title and axis. You can view other files in folder even if you just open a file.
- version 0.1 on 2020/12/22: view .sxm files and folders. First version. A memorable day.

